@@ -9,7 +9,7 @@ from datetime import datetime
 import requests
 import logging
 import shutil
-from learning_loop_node.globals import GLOBALS
+from ..globals import GLOBALS
 
 
 class Outbox():
